#-----------------------------------------------------------------------
# File    : regress.mak
# Contents: build regression program
# Author  : Christian Borgelt
# History : 2003.01.27 file created
#           2006.07.20 adapted to Visual Studio 8
#           2016.04.20 completed dependencies on header files
#-----------------------------------------------------------------------
THISDIR  = ..\..\regress\src
UTILDIR  = ..\..\util\src
MATHDIR  = ..\..\math\src
MATDIR   = ..\..\matrix\src
TABLEDIR = ..\..\table\src

CC       = cl.exe
DEFS     = /D WIN32 /D NDEBUG /D _CONSOLE /D _CRT_SECURE_NO_WARNINGS
CFLAGS   = /nologo /W3 /O2 /GS- $(DEFS) /c
INCS     = /I $(UTILDIR) /I $(MATDIR) /I $(MATHDIR) /I $(TABLEDIR)

LD       = link.exe
LDFLAGS  = /nologo /subsystem:console /incremental:no
LIBS     = 

HDRS_REG = $(UTILDIR)\fntypes.h    $(UTILDIR)\scanner.h    \
           $(MATDIR)\matrix.h      $(TABLEDIR)\attset.h    \
           $(TABLEDIR)\attmap.h    $(TABLEDIR)\table.h
HDRS     = $(HDRS_REG)             $(UTILDIR)\error.h      \
           $(UTILDIR)\tabread.h    regress.h
OBJS     = $(UTILDIR)\arrays.obj   $(UTILDIR)\escape.obj   \
           $(UTILDIR)\tabread.obj  $(UTILDIR)\tabwrite.obj \
           $(UTILDIR)\scanner.obj  $(MATDIR)\mat_rdwr.obj  \
           $(MATDIR)\matrix2.obj   $(TABLEDIR)\attset1.obj \
           $(TABLEDIR)\attset2.obj $(TABLEDIR)\attset3.obj \
           $(TABLEDIR)\attmap.obj  $(ADDOBJS)
TABOBJS  = $(TABLEDIR)\table1.obj  $(TABLEDIR)\tab2rm.obj
MPR_O    = $(OBJS) $(TABOBJS) $(UTILDIR)\params.obj \
           reg_ext.obj mpr.obj
MPX_O    = $(OBJS) $(TABOBJS) reg_pars.obj mpx.obj
KELR_O   = $(UTILDIR)\params.o     $(MATHDIR)\radfn.o      \
           $(MATHDIR)\gamma.o      $(OBJS) kelr.o
PRGS     = mpr.exe mpx.exe

#-----------------------------------------------------------------------
# Build Program
#-----------------------------------------------------------------------
all:          $(PRGS)

mpr.exe:      $(MPR_O) regress.mak
	$(LD) $(LDFLAGS) $(MPR_O) $(LIBS) /out:$@

mpx.exe:      $(MPX_O) regress.mak
	$(LD) $(LDFLAGS) $(MPX_O) $(LIBS) /out:$@

kelr.exe:     $(KELR_O) regress.mak
	$(LD) $(LDFLAGS) $(KELR_O) $(LIBS) /out:$@

#-----------------------------------------------------------------------
# Main Programs
#-----------------------------------------------------------------------
mpr.obj:      $(HDRS) $(UTILDIR)\arrays.h $(UTILDIR)\params.h
mpr.obj:      mpr.c regress.mak
	$(CC) $(CFLAGS) $(INCS) mpr.c /Fo$@

mpx.obj:      $(HDRS) $(UTILDIR)\tabwrite.h
mpx.obj:      mpx.c regress.mak
	$(CC) $(CFLAGS) $(INCS) mpx.c /Fo$@

kelr.obj:     $(UTILDIR)\params.h   $(UTILDIR)\error.h \
              $(UTILDIR)\tabread.h  $(MATHDIR)\radfn.h \
              $(MATDIR)\matrix.h
kelr.obj:     kelr.c regress.mak
	$(CC) $(CFLAGS) $(INCS) kelr.c /Fo$@

#-----------------------------------------------------------------------
# Multivariate Polynomial Regression
#-----------------------------------------------------------------------
regress.obj:  $(MATDIR)\matrix.h
regress.obj:  regress.h regress.c regress.mak
	$(CC) $(CFLAGS) $(INCS) regress.c /Fo$@

reg_ext.obj:  $(HDRS_REG)
reg_ext.obj:  regress.h regress.c regress.mak
	$(CC) $(CFLAGS) $(INCS) /D REG_EXTFN regress.c /Fo$@

reg_pars.obj: $(HDRS_REG)
reg_pars.obj: regress.h regress.c regress.mak
	$(CC) $(CFLAGS) $(INCS) /D REG_EXTFN /D REG_PARSE \
              regress.c /Fo$@

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(UTILDIR)\arrays.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak arrays.obj
	cd $(THISDIR)
$(UTILDIR)\escape.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak escape.obj
	cd $(THISDIR)
$(UTILDIR)\tabread.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabread.obj
	cd $(THISDIR)
$(UTILDIR)\tabwrite.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabwrite.obj
	cd $(THISDIR)
$(UTILDIR)\scanner.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak scanner.obj
	cd $(THISDIR)
$(UTILDIR)\params.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak params.obj
	cd $(THISDIR)
$(MATHDIR)\gamma.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak gamma.obj
	cd $(THISDIR)
$(MATHDIR)\radfn.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak radfn.obj
	cd $(THISDIR)
$(MATDIR)\mat_rdwr.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak mat_rdwr.obj
	cd $(THISDIR)
$(MATDIR)\matrix2.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix2.obj
	cd $(THISDIR)
$(TABLEDIR)\attset1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset1.obj
	cd $(THISDIR)
$(TABLEDIR)\attset2.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset2.obj
	cd $(THISDIR)
$(TABLEDIR)\attset3.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset3.obj
	cd $(THISDIR)
$(TABLEDIR)\attmap.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attmap.obj
	cd $(THISDIR)
$(TABLEDIR)\table1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak table1.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2ro.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2ro.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2rm.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2rm.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy *.exe ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
localclean:
	-@erase /Q *~ *.obj *.idb *.pch $(PRGS)

clean:
	$(MAKE) /f regress.mak localclean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(MATDIR)
	$(MAKE) /f matrix.mak localclean
	cd $(TABLEDIR)
	$(MAKE) /f table.mak localclean
	cd $(THISDIR)
